@@ -289,8 +289,8 @@ class MetatraderOrder(TypedDict):
     """Order symbol."""
     openPrice: float
     """Order open price (market price for market orders, limit price for limit orders or stop price for stop orders)."""
-    currentPrice: float
-    """Current price."""
+    currentPrice: Optional[float]
+    """Current price, filled for pending orders only. Not filled for history orders."""
     stopLoss: Optional[float]
     """Optional order stop loss price."""
     takeProfit: Optional[float]
@@ -571,8 +571,8 @@ class MetatraderSymbolPrice(TypedDict):
     """Tick value for a loosing position."""
     accountCurrencyExchangeRate: float
     """Current exchange rate of account currency into account base currency (USD if you did not override it)."""
-    time: str
-    """Quote time, in ISO format"""
+    time: datetime
+    """Quote time."""
     brokerTime: str
     """Quote time, in broker timezone, YYYY-MM-DD HH:mm:ss.SSS format."""
 
